/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 2; tab-width: 2 -*- */
/* gdome-xml-eventl.c
 *
 * Copyright (C) 1999 Raph Levien <raph@acm.org>
 * Copyright (C) 2000 Mathieu Lacage <mathieu@gnu.org>
 * Copyright (C) 2001 Paolo Casarini <paolo@casarini.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA  02111-1307, USA.
 */

#include <stdlib.h>
#include <string.h>
#include "gdome.h"
#include "gdome-events.h"
#include "gdome-util.h"
#include "gdome-xml-util.h"
#include "gdome-evt-eventl.h"
#include "gdome-evt-event.h"


const GdomeEventListenerVtab gdome_evt_evntl_vtab =
{
  gdome_evt_evntl_ref,
  gdome_evt_evntl_unref,
  gdome_evt_evntl_query_interface,
  gdome_evt_evntl_handleEvent
};


GdomeEventListener * 
gdome_evt_evntl_mkref (void (*callback) (GdomeEventListener *self,
																				 GdomeEvent *event, 
																				 GdomeException *exc), 
											 void *priv)
{
  Gdome_evt_EventListener *result = NULL;

  result = g_new (Gdome_evt_EventListener, 1);
  result->refcnt = 1;
  result->super.vtab = (GdomeEventListenerVtab *) &gdome_evt_evntl_vtab;

  result->callback = callback;
  result->priv = priv;

  return (GdomeEventListener *)result;
}


/* 
	 an extension to the DOM spec. You can attach abitrary data
	 to the listener and get it back through this function
	 when the listener is called.
	 This is used specifically by Gill.
	 It is baaaad. I need to find another way to do this fast.
*/
void *
gdome_evt_evntl_get_priv (GdomeEventListener *self)
{
  Gdome_evt_EventListener *priv = (Gdome_evt_EventListener *) self;

  g_return_val_if_fail (priv != NULL, NULL);
  g_return_val_if_fail (GDOME_XML_IS_EVNTL (priv), NULL);

  return priv->priv;
}

void
gdome_evt_evntl_ref (GdomeEventListener *self, GdomeException *exc)
{
  Gdome_evt_EventListener *priv = (Gdome_evt_EventListener *)self;

  g_return_if_fail (priv != NULL);
  g_return_if_fail (GDOME_XML_IS_EVNTL (priv));
  g_return_if_fail (exc != NULL);

  priv->refcnt++;
}

void
gdome_evt_evntl_unref (GdomeEventListener *self, GdomeException *exc)
{
  Gdome_evt_EventListener *priv = (Gdome_evt_EventListener *)self;

  g_return_if_fail (priv != NULL);
  g_return_if_fail (GDOME_XML_IS_EVNTL (priv));
  g_return_if_fail (exc != NULL);

  if (--priv->refcnt == 0) {
		g_free (self);
  }

}

void *
gdome_evt_evntl_query_interface (GdomeEventListener *self, const char *interface, GdomeException *exc)
{
  Gdome_evt_EventListener *priv = (Gdome_evt_EventListener *)self;

  g_return_val_if_fail (priv != NULL, NULL);
  g_return_val_if_fail (GDOME_XML_IS_EVNTL (priv), NULL);
  g_return_val_if_fail (interface != NULL, NULL);
  g_return_val_if_fail (exc != NULL, NULL);

  if (!strcmp (interface, "EventListener")) {
		priv->refcnt++;

		return self;
	}
  else
    return NULL;
}

void
gdome_evt_evntl_handleEvent (GdomeEventListener *self, GdomeEvent *event, GdomeException *exc)
{
  Gdome_evt_EventListener *priv = (Gdome_evt_EventListener *) self;

  g_return_if_fail (priv != NULL);
  g_return_if_fail (GDOME_XML_IS_EVNTL (priv));
  g_return_if_fail (event != NULL);
  g_return_if_fail (GDOME_XML_IS_EVNT (event));
  g_return_if_fail (exc != NULL);

  priv->callback (self, event, exc);
}
