/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 2; tab-width: 2 -*- */
/* gdome-events.c
 *
 * Copyright (C) 1999 Raph Levien <raph@acm.org>
 * Copyright (C) 2000 Mathieu Lacage <mathieu@gnu.org>
 * CopyRight (C) 2001 Paolo Casarini <paolo@casarini.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA  02111-1307, USA.
 */

/* ----- gdome-events.c ----- */
#include "gdome-events.h"
#include "gdome-evt-eventl.h"
#include "gdome-evt-event.h"
#include "gdome-evt-mevent.h"

GdomeEvent *
gdome_evnt_mkref (void)
{
  return gdome_evt_evnt_mkref();
}

void
gdome_evnt_ref (GdomeEvent *self, GdomeException *exc)
{
	g_return_if_fail (self != NULL);
	*exc = 0;
	self->vtab->ref (self, exc);
}

void
gdome_evnt_unref (GdomeEvent *self, GdomeException *exc)
{
	g_return_if_fail (self != NULL);
	*exc = 0;
	self->vtab->unref (self, exc);
}

void *
gdome_evnt_query_interface (GdomeEvent *self, const char *interface, GdomeException *exc)
{
	g_return_val_if_fail (self != NULL, NULL);
	*exc = 0;
	return self->vtab->query_interface (self, interface, exc);
}

GdomeDOMString *
gdome_evnt_type (GdomeEvent *self, GdomeException *exc)
{
	g_return_val_if_fail (self != NULL, NULL);
	*exc = 0;
	return self->vtab->type (self, exc);
}

GdomeNode *
gdome_evnt_target (GdomeEvent *self, GdomeException *exc)
{
	g_return_val_if_fail (self != NULL, NULL);
	*exc = 0;
	return self->vtab->target (self, exc);
}

GdomeNode *
gdome_evnt_currentTarget (GdomeEvent *self, GdomeException *exc)
{
	g_return_val_if_fail (self != NULL, NULL);
	*exc = 0;
	return self->vtab->currentTarget (self, exc);
}

unsigned short
gdome_evnt_eventPhase (GdomeEvent *self, GdomeException *exc)
{
	g_return_val_if_fail (self != NULL, 0);
	*exc = 0;
	return self->vtab->eventPhase (self, exc);
}

GdomeBoolean
gdome_evnt_bubbles (GdomeEvent *self, GdomeException *exc)
{
	g_return_val_if_fail (self != NULL, FALSE);
	*exc = 0;
	return self->vtab->bubbles (self, exc);
}

GdomeBoolean
gdome_evnt_cancelable (GdomeEvent *self, GdomeException *exc)
{
	g_return_val_if_fail (self != NULL, FALSE);
	*exc = 0;
	return self->vtab->cancelable (self, exc);
}

GdomeDOMTimeStamp
gdome_evnt_timeStamp (GdomeEvent *self, GdomeException *exc)
{
	g_return_val_if_fail (self != NULL, FALSE);
	*exc = 0;
	return self->vtab->timeStamp (self, exc);
}

void
gdome_evnt_stopPropagation (GdomeEvent *self, GdomeException *exc)
{
	g_return_if_fail (self != NULL);
	*exc = 0;
	self->vtab->stopPropagation (self, exc);
}

void
gdome_evnt_preventDefault (GdomeEvent *self, GdomeException *exc)
{
	g_return_if_fail (self != NULL);
	*exc = 0;
	self->vtab->preventDefault (self, exc);
}

void
gdome_evnt_initEvent (GdomeEvent *self, GdomeDOMString *eventTypeArg, GdomeBoolean canBubbleArg, GdomeBoolean cancelableArg, GdomeException *exc)
{
	g_return_if_fail (self != NULL);
	*exc = 0;
	self->vtab->initEvent (self, eventTypeArg, canBubbleArg, cancelableArg, exc);
}

GdomeEventListener *gdome_evntl_mkref (void (*callback) (GdomeEventListener *self,
                                                         GdomeEvent *event,
                                                         GdomeException *exc),
                                       void *priv)
{
	return gdome_evt_evntl_mkref (callback, priv);
}

void
gdome_evntl_ref (GdomeEventListener *self, GdomeException *exc)
{
	g_return_if_fail (self != NULL);
	*exc = 0;
	self->vtab->ref (self, exc);
}

void
gdome_evntl_unref (GdomeEventListener *self, GdomeException *exc)
{
	g_return_if_fail (self != NULL);
	*exc = 0;
	self->vtab->unref (self, exc);
}

void *
gdome_evntl_query_interface (GdomeEventListener *self, const char *interface, GdomeException *exc)
{
	g_return_val_if_fail (self != NULL, NULL);
	*exc = 0;
	return self->vtab->query_interface (self, interface, exc);
}

void
gdome_evntl_handleEvent (GdomeEventListener *self, GdomeEvent *event, GdomeException *exc)
{
	g_return_if_fail (self != NULL);
	*exc = 0;
	self->vtab->handleEvent (self, event, exc);
}

GdomeMutationEvent *
gdome_mevnt_mkref (void)
{
  return gdome_evt_mevnt_mkref();
}

GdomeNode *
gdome_mevnt_relatedNode (GdomeMutationEvent *self, GdomeException *exc)
{
	g_return_val_if_fail (self != NULL, NULL);
	*exc = 0;
	return self->vtab->relatedNode (self, exc);
}

GdomeDOMString *
gdome_mevnt_prevValue (GdomeMutationEvent *self, GdomeException *exc)
{
	g_return_val_if_fail (self != NULL, NULL);
	*exc = 0;
	return self->vtab->prevValue (self, exc);
}

GdomeDOMString *
gdome_mevnt_newValue (GdomeMutationEvent *self, GdomeException *exc)
{
	g_return_val_if_fail (self != NULL, NULL);
	*exc = 0;
	return self->vtab->newValue (self, exc);
}

GdomeDOMString *
gdome_mevnt_attrName (GdomeMutationEvent *self, GdomeException *exc)
{
	g_return_val_if_fail (self != NULL, NULL);
	*exc = 0;
	return self->vtab->attrName (self, exc);
}

void
gdome_mevnt_initMutationEvent (GdomeMutationEvent *self, GdomeDOMString *typeArg, GdomeBoolean canBubbleArg, GdomeBoolean cancelableArg, GdomeNode *relatedNodeArg, GdomeDOMString *prevValueArg, GdomeDOMString *newValueArg, GdomeDOMString *attrNameArg, unsigned short attrChangeArg, GdomeException *exc)
{
	g_return_if_fail (self != NULL);
	*exc = 0;
	self->vtab->initMutationEvent (self, typeArg, canBubbleArg, cancelableArg, relatedNodeArg, prevValueArg, newValueArg, attrNameArg, attrChangeArg, exc);
}

/* gen_invoker_super GdomeMutationEvent mevnt MutationEvent: Event ()*/
void
gdome_mevnt_ref (GdomeMutationEvent *self, GdomeException *exc)
{
	g_return_if_fail (self != NULL);
	*exc = 0;
	self->vtab->super.ref ((GdomeEvent *)self, exc);
}

void
gdome_mevnt_unref (GdomeMutationEvent *self, GdomeException *exc)
{
	g_return_if_fail (self != NULL);
	*exc = 0;
	self->vtab->super.unref ((GdomeEvent *)self, exc);
}

void *
gdome_mevnt_query_interface (GdomeMutationEvent *self, const char *interface, GdomeException *exc)
{
	g_return_val_if_fail (self != NULL, NULL);
	*exc = 0;
	return self->vtab->super.query_interface ((GdomeEvent *)self, interface, exc);
}

GdomeDOMString *
gdome_mevnt_type (GdomeMutationEvent *self, GdomeException *exc)
{
	g_return_val_if_fail (self != NULL, NULL);
	*exc = 0;
	return self->vtab->super.type ((GdomeEvent *)self, exc);
}

GdomeNode *
gdome_mevnt_target (GdomeMutationEvent *self, GdomeException *exc)
{
	g_return_val_if_fail (self != NULL, NULL);
	*exc = 0;
	return self->vtab->super.target ((GdomeEvent *)self, exc);
}

GdomeNode *
gdome_mevnt_currentTarget (GdomeMutationEvent *self, GdomeException *exc)
{
	g_return_val_if_fail (self != NULL, NULL);
	*exc = 0;
	return self->vtab->super.currentTarget ((GdomeEvent *)self, exc);
}

unsigned short
gdome_mevnt_eventPhase (GdomeMutationEvent *self, GdomeException *exc)
{
	g_return_val_if_fail (self != NULL, 0);
	*exc = 0;
	return self->vtab->super.eventPhase ((GdomeEvent *)self, exc);
}

GdomeBoolean
gdome_mevnt_bubbles (GdomeMutationEvent *self, GdomeException *exc)
{
	g_return_val_if_fail (self != NULL, FALSE);
	*exc = 0;
	return self->vtab->super.bubbles ((GdomeEvent *)self, exc);
}

GdomeBoolean
gdome_mevnt_cancelable (GdomeMutationEvent *self, GdomeException *exc)
{
	g_return_val_if_fail (self != NULL, FALSE);
	*exc = 0;
	return self->vtab->super.cancelable ((GdomeEvent *)self, exc);
}

GdomeDOMTimeStamp
gdome_mevnt_timeStamp (GdomeMutationEvent *self, GdomeException *exc)
{
	g_return_val_if_fail (self != NULL, FALSE);
	*exc = 0;
	return self->vtab->super.timeStamp ((GdomeEvent *)self, exc);
}

void
gdome_mevnt_stopPropagation (GdomeMutationEvent *self, GdomeException *exc)
{
	g_return_if_fail (self != NULL);
	*exc = 0;
	self->vtab->super.stopPropagation ((GdomeEvent *)self, exc);
}

void
gdome_mevnt_preventDefault (GdomeMutationEvent *self, GdomeException *exc)
{
	g_return_if_fail (self != NULL);
	*exc = 0;
	self->vtab->super.preventDefault ((GdomeEvent *)self, exc);
}

void
gdome_mevnt_initEvent (GdomeMutationEvent *self, GdomeDOMString *eventTypeArg, GdomeBoolean canBubbleArg, GdomeBoolean cancelableArg, GdomeException *exc)
{
	g_return_if_fail (self != NULL);
	*exc = 0;
	self->vtab->super.initEvent ((GdomeEvent *)self, eventTypeArg, canBubbleArg, cancelableArg, exc);
}

/*long
gdome_uievnt_screenX (GdomeUIEvent *self, GdomeException *exc)
{
	g_return_val_if_fail (self != NULL, 0L);
	*exc = 0;
	return self->vtab->screenX (self, exc);
}

void
gdome_uievnt_set_screenX (GdomeUIEvent *self, long screenX, GdomeException *exc)
{
	g_return_if_fail (self != NULL);
	*exc = 0;
	self->vtab->set_screenX (self, screenX, exc);
}

long
gdome_uievnt_screenY (GdomeUIEvent *self, GdomeException *exc)
{
	g_return_val_if_fail (self != NULL, 0L);
	*exc = 0;
	return self->vtab->screenY (self, exc);
}

void
gdome_uievnt_set_screenY (GdomeUIEvent *self, long screenY, GdomeException *exc)
{
	g_return_if_fail (self != NULL);
	*exc = 0;
	self->vtab->set_screenY (self, screenY, exc);
}

long
gdome_uievnt_clientX (GdomeUIEvent *self, GdomeException *exc)
{
	g_return_val_if_fail (self != NULL, 0L);
	*exc = 0;
	return self->vtab->clientX (self, exc);
}

void
gdome_uievnt_set_clientX (GdomeUIEvent *self, long clientX, GdomeException *exc)
{
	g_return_if_fail (self != NULL);
	*exc = 0;
	self->vtab->set_clientX (self, clientX, exc);
}

long
gdome_uievnt_clientY (GdomeUIEvent *self, GdomeException *exc)
{
	g_return_val_if_fail (self != NULL, 0L);
	*exc = 0;
	return self->vtab->clientY (self, exc);
}

void
gdome_uievnt_set_clientY (GdomeUIEvent *self, long clientY, GdomeException *exc)
{
	g_return_if_fail (self != NULL);
	*exc = 0;
	self->vtab->set_clientY (self, clientY, exc);
}

GdomeBoolean
gdome_uievnt_altKey (GdomeUIEvent *self, GdomeException *exc)
{
	g_return_val_if_fail (self != NULL, FALSE);
	*exc = 0;
	return self->vtab->altKey (self, exc);
}

void
gdome_uievnt_set_altKey (GdomeUIEvent *self, GdomeBoolean altKey, GdomeException *exc)
{
	g_return_if_fail (self != NULL);
	*exc = 0;
	self->vtab->set_altKey (self, altKey, exc);
}

GdomeBoolean
gdome_uievnt_ctrlKey (GdomeUIEvent *self, GdomeException *exc)
{
	g_return_val_if_fail (self != NULL, FALSE);
	*exc = 0;
	return self->vtab->ctrlKey (self, exc);
}

void
gdome_uievnt_set_ctrlKey (GdomeUIEvent *self, GdomeBoolean ctrlKey, GdomeException *exc)
{
	g_return_if_fail (self != NULL);
	*exc = 0;
	self->vtab->set_ctrlKey (self, ctrlKey, exc);
}

GdomeBoolean
gdome_uievnt_shiftKey (GdomeUIEvent *self, GdomeException *exc)
{
	g_return_val_if_fail (self != NULL, FALSE);
	*exc = 0;
	return self->vtab->shiftKey (self, exc);
}

void
gdome_uievnt_set_shiftKey (GdomeUIEvent *self, GdomeBoolean shiftKey, GdomeException *exc)
{
	g_return_if_fail (self != NULL);
	*exc = 0;
	self->vtab->set_shiftKey (self, shiftKey, exc);
}

unsigned long
gdome_uievnt_keyCode (GdomeUIEvent *self, GdomeException *exc)
{
	g_return_val_if_fail (self != NULL, 0L);
	*exc = 0;
	return self->vtab->keyCode (self, exc);
}

void
gdome_uievnt_set_keyCode (GdomeUIEvent *self, unsigned long keyCode, GdomeException *exc)
{
	g_return_if_fail (self != NULL);
	*exc = 0;
	self->vtab->set_keyCode (self, keyCode, exc);
}

unsigned long
gdome_uievnt_charCode (GdomeUIEvent *self, GdomeException *exc)
{
	g_return_val_if_fail (self != NULL, 0L);
	*exc = 0;
	return self->vtab->charCode (self, exc);
}

void
gdome_uievnt_set_charCode (GdomeUIEvent *self, unsigned long charCode, GdomeException *exc)
{
	g_return_if_fail (self != NULL);
	*exc = 0;
	self->vtab->set_charCode (self, charCode, exc);
}

unsigned short
gdome_uievnt_button (GdomeUIEvent *self, GdomeException *exc)
{
	g_return_val_if_fail (self != NULL, 0);
	*exc = 0;
	return self->vtab->button (self, exc);
}

void
gdome_uievnt_set_button (GdomeUIEvent *self, unsigned short button, GdomeException *exc)
{
	g_return_if_fail (self != NULL);
	*exc = 0;
	self->vtab->set_button (self, button, exc);
}

/* gen_invoker_super GdomeUIEvent uievnt UIEvent: Event ()*/
/*void
gdome_uievnt_ref (GdomeUIEvent *self, GdomeException *exc)
{
	g_return_if_fail (self != NULL);
	*exc = 0;
	self->vtab->super.ref ((GdomeEvent *)self, exc);
}

void
gdome_uievnt_unref (GdomeUIEvent *self, GdomeException *exc)
{
	g_return_if_fail (self != NULL);
	*exc = 0;
	self->vtab->super.unref ((GdomeEvent *)self, exc);
}

void *
gdome_uievnt_query_interface (GdomeUIEvent *self, const char *interface, GdomeException *exc)
{
	g_return_val_if_fail (self != NULL, NULL);
	*exc = 0;
	return self->vtab->super.query_interface ((GdomeEvent *)self, interface, exc);
}

GdomeDOMString *
gdome_uievnt_type (GdomeUIEvent *self, GdomeException *exc)
{
	g_return_val_if_fail (self != NULL, NULL);
	*exc = 0;
	return self->vtab->super.type ((GdomeEvent *)self, exc);
}

GdomeNode *
gdome_uievnt_target (GdomeUIEvent *self, GdomeException *exc)
{
	g_return_val_if_fail (self != NULL, NULL);
	*exc = 0;
	return self->vtab->super.target ((GdomeEvent *)self, exc);
}

GdomeNode *
gdome_uievnt_currentTarget (GdomeUIEvent *self, GdomeException *exc)
{
	g_return_val_if_fail (self != NULL, NULL);
	*exc = 0;
	return self->vtab->super.currentTarget ((GdomeEvent *)self, exc);
}

unsigned short
gdome_uievnt_eventPhase (GdomeUIEvent *self, GdomeException *exc)
{
	g_return_val_if_fail (self != NULL, 0);
	*exc = 0;
	return self->vtab->super.eventPhase ((GdomeEvent *)self, exc);
}

GdomeBoolean
gdome_uievnt_bubbles (GdomeUIEvent *self, GdomeException *exc)
{
	g_return_val_if_fail (self != NULL, FALSE);
	*exc = 0;
	return self->vtab->super.bubbles ((GdomeEvent *)self, exc);
}

GdomeBoolean
gdome_uievnt_cancelable (GdomeUIEvent *self, GdomeException *exc)
{
	g_return_val_if_fail (self != NULL, FALSE);
	*exc = 0;
	return self->vtab->super.cancelable ((GdomeEvent *)self, exc);
}

GdomeDOMTimeStamp
gdome_uievnt_timeStamp (GdomeUIEvent *self, GdomeException *exc)
{
	g_return_val_if_fail (self != NULL, FALSE);
	*exc = 0;
	return self->vtab->super.timeStamp ((GdomeEvent *)self, exc);
}

void
gdome_uievnt_stopPropagation (GdomeUIEvent *self, GdomeException *exc)
{
	g_return_if_fail (self != NULL);
	*exc = 0;
	self->vtab->super.stopPropagation ((GdomeEvent *)self, exc);
}

void
gdome_uievnt_preventDefault (GdomeUIEvent *self, GdomeException *exc)
{
	g_return_if_fail (self != NULL);
	*exc = 0;
	self->vtab->super.preventDefault ((GdomeEvent *)self, exc);
}

void
gdome_uievnt_initEvent (GdomeUIEvent *self, GdomeDOMString *eventTypeArg, GdomeBoolean canBubbleArg, GdomeBoolean cancelableArg, GdomeException *exc)
{
	g_return_if_fail (self != NULL);
	*exc = 0;
	self->vtab->super.initEvent ((GdomeEvent *)self, eventTypeArg, canBubbleArg, cancelableArg, exc);
}
  */